@@ -10,7 +10,7 @@
 #include <KIO/Job>
 #include <KIO/JobUiDelegate>
 #include <KIO/TransferJob>
-#include <KJobWidgets/KJobWidgets>
+#include <KJobWidgets>
 
 using namespace Akonadi;
 
@@ -21,9 +21,7 @@ FreeBusyDownloadJob::FreeBusyDownloadJob(const QUrl &url, QWidget *parentWidget)
     setObjectName(QStringLiteral("FreeBusyDownloadJob"));
 }
 
-FreeBusyDownloadJob::~FreeBusyDownloadJob()
-{
-}
+FreeBusyDownloadJob::~FreeBusyDownloadJob() = default;
 
 void FreeBusyDownloadJob::start()
 {
